# Audiocite.net : A Spoken Read Dataset in French

**Date**: March 2023

**Contributors**: Solène Evain, François Portet, Fabien Ringeval, Soline Felice

**Goal**: Preparation of Audiocite.net data, initially collected for the LeBenchmark project

**Total Duration**: 6682 hours of audio containing speech by 130 speakers

Audiocite.net is a corpus of read French speech accompanied by metadata (name of audio files, file paths, duration of audio, name and gender of the speakers).

With a total duration of 6682 hours of audio recording, this corpus is the result of the voluntary work of 130 speakers.
The metadata is divided into 4 .jsons files (all(100%), train(80%), dev(10%) and test(10%)) to be used in NLP models.

The corpus and its metadata were uploaded through a script distributing the information in a .csv file. The audio files and this metadata file were downloaded in November 2021 from the Audiocite.net website: https://www.audiocite.net/. The use of these audio and metadata files is intended for pre-trained speech models.

## Overview of the Corpus

The recordings were made by the readers themselves in conditions suitable for recording.
They were downloaded from the Audiocite.net website, which provides the metadata associated with each audio.
The information which is coming from the website is the author of the book, the title, the reader, the license and the category of the book.
We have filled the metadata with other information as the gender of the speaker (cf. section Metadata and section Warning) which gave us the following statistics :

| Speakers Gender*|    Number of Files   | Number of Speakers | Total Duration | Avg. Duration | Min. Duration | Max. Duration |
|-----------------| -------------------- | ------------------ | -------------  | ------------- | ------------- | ------------- |
|        M        |        19345         |         51         |   4127:34:45   |    00:12:48   |    00:15:01   |    06:39:43   |
|        F        |         8261         |         70         |   2272:18:23   |    00:16:30   |    00:03:49   |    02:46:06   |
|        U        |          879         |          9         |    282:07:09   |    00:19:15   |    00:00:09   |    03:30:16   |
|      Total      |        28485         |        130         |   6682:00:18   |    00:14:04   |    00:00:09   |    06:39:43   |

*Beware speaker gender has been guessed and should not be considered as ground truth (cf. section Metadata and section Warning)

## Usage rights/License

The rights of use of the audios are different for each file (some works being in the public domain).
In the .csv file (metadata/downloaded.csv), you can find the license corresponding to each reading (5th column "license").
The audios are all under a "Creative Commons BY (attribution)" license but with different modifications and sharing subtleties depending on the audio:  

    - CC BY (Public domain)
    - CC BY SA (Share alike)
    - CC BY ND (No modification)
    - CC BY NC (No commercial use)
    --> or combination of the above

## Warning

The recordings may contain explicit content that addresses adult themes, including sex, violence, vulgarity, or that may be offensive to certain groups of people. If a recording is deemed inappropriate, it may be reported to the authors of the corpus, who may remove it.

The recordings are provided as is, with minimal processing. Thus, some recordings may contain background music, noise, or unexpected speakers. Moreover, except for a few cases, the original mp3 encoding has been preserved, which means that some recordings are mono while others are stereo and that there are different bit rates.

Finally, gender information was inferred from the first name of the authors, with verification upon listening in case of ambiguity. The perceived classification is entirely subjective and may not respect the speaker's opinion of his or her gender (we did not find any information about this on the audiocite.net website). This information should not be considered as ground truth and is only intended to be used for a rough statistical estimate. For example, some manual checks have revealed that when a single speaker is supposed to have read a book, multiple speakers may be heard or a different voice may be heard.

The speaker/sex assignment is reported in a specific file. Pseudonyms are reported as they were written on the Audiocite.net website. No processing has been done to find out the real identity of the person(s) behind the pseudonym, although we cannot guarantee that it cannot be discovered. Furthermore, since most of the recordings are provided under a Creative Commons BY (attribution) license, the name (pseudonym) must be preserved in order to acknowledge the speaker's work.

## Citation

Please cite the website Audiocite.net (https://www.audiocite.net/) if you use our data for your own research.

## Structure of the project

The corpus contains the following elements

.
├── wavs/
├──── directory1/audio1.mp3
├──── directory1/audio2.mp3
├──── directory2/extracted/audio3.mp3
├──── ...
├── metadata/
├──── downloaded.csv
├──── ids_gender.txt
├──── all_files.json 
├──── dev_files.json
├──── test_files.json
├──── train_files.json
├── scripts
├──── archiving_and_split.sh
├──── prep_json_metadata.py
├──── prep_json_partitioning.py.py
├──── prep_json_filter.py
├──── utils.py
├──── funcs.py
├──── get_json_stats.py
├── datasheet_audiocite.pdf
└── README.md

### Paths

The .mp3 files are stored in associated folders, and sometimes in an "extracted" folder.

Example of folders in the *wavs* folder:

Reading0/extracted/reading_0.mp3
Reading1/reading_1.mp3
Reading2/extracted/reading_2.mp3, reading_2.mp3, reading_2.mp3

### Metadata

**Json Files**:

The .json files give the following information :
- the audio ID :
	- the path
	- the duration of the audio file
	- the speaker's ID
	- the speaker's gender*
This information was retrieved from the Audiocite.net website through a script putting all the metadata in the file dowloaded.csv.

Example of a record of a json file :

  "DemainDesLaube_VictorHugo_LesContemplations_1856_.mp3": {
    "path": "../wavs/DemainDesLaube_VictorHugo_LesContemplations_1856_/DemainDesLaube_VictorHugo_LesContemplations_1856_.mp3",
    "trans": "",
    "duration": 80.169,
    "spk_id": "Charlesdeleusse",
    "spk_gender": "M"
  },

NB* : The gender information has been discovered by guessing based on the speaker's name (example : speaker ID: Emma so the speaker gender: F) or by listening to the voice of the speaker. We therefore do not certify the information is reliable, nor do we certify that the method used is viable for deducing a person's gender. Gender data should be treated with caution.

**Csv file**:

The .csv file containing all the audio files and their metadata is made of 8 columns: title;audio_url;author;category;license;speaker;book_url;directory

Example line:

Demain, dès l’aube;https://ia802909.us.archive.org/28/items/demain-des-laube-victor-hugo-les-contemplations-1856/DemainDesLaube_VictorHugo_LesContemplations%281856%29.mp3;Victor Hugo;poesies;[('http://creativecommons.fr/licences/', 'Creative Commons BY (attribution) NC (Pas d'utilisation commerciale) ND (Pas de modification)')];Charlesdeleusse;https://www.audiocite.net/livres-audio-gratuits-poesies/victor-hugo-demain--des-l'aube.html;wavs/DemainDesLaube_VictorHugo_LesContemplations_1856_/

The first column corresponds to the title of the writing, the second to the URL of the audio file or achive, the third to the entity who uploaded the recording, the fourth to the category of the book (novels, science fiction, etc.), the fifth to the license that protects the writing and the audio, the sixth to the readers (often the same as the fourth), the seventh to the webpage of the audiobook on audiocite.net and the eighth to the path where to find the .mp3 files in the dataset.

**Python Scripts**:

Three python scripts are needed to get the 4 split jsons : all_files.json, dev_files.json, test_files.json and train_files.json.

1. prep_json_metadata.py
	- path : ./scripts/prep_json_metadata.py
	- input file : 
		- ./metadata/downloaded.csv
		- ./metadata/ids_gender.txt
	- needed file :
		- ./scripts/funcs.py
	- output file :
		- ./metadata/all_files.json
	- goal :
		- Get the information related to each audio in the .csv and create a json file with the information of each audio (path, duration, speaker id and their gender)

2. prep_json_filter.py
	- path : ./scripts/prep_json_filter.py
	- input file : 
		- ./metadata/downloaded.csv
		- ./metadata/ids_gender.txt
	- needed file :
		- ./scripts/funcs.py
	- output file :
		- ./metadata/all_filtered_files.json
	- goal :
		- Get the same information as the previous script except the audio with content that may be considered sensitive (files whose writing categories are "charmes" (erotic), "planete-actuelle" (geopolitics) and "religions"). This is what we call the filtered data.

3. prep_json_partitioning.py
	- path : ./scripts/prep_json_partitioning.py
	- input file : 
		- ./metadata/downloaded.csv
		- ./metadata/ids_gender.txt
	- needed file :
		- ./metadata/all_filtered_files.json
		- ./metadata/all_files.json
	- output file :
		- ./metadata/dev_files.json
		- ./metadata/test_files.json
		- ./metadata/train_files.json
	- goal :
		- Create three json files containing the information of the file "all_files.json" splits :
			- dev_files.json which contains around 10% of the total duration of the audios, and that filtered files (present in the file "all_filtered_files.json" but without the file where the gender of the speaker is labeled Unknown )
			- test_files.json which contains the 10% the next 10% of the total duration of the audio files with only filtered files as well
			- train_files.json which contains all the other files not embedded yet into the dev_files.json or the test_files.json (and corresponds to the remaining 80% of the total duration)

4. (*optional*) get_json_stats.py
	- path : ./scripts/get_json_stats.py
	- input file : 
		- *name of the json file you want to get the stats from*
	- needed file :
		- ./scripts/utils.py
	- output file :
		- ./metadata/*the_json_file*_stats.csv
	- goal :
		- Get statistics related to any json file :
			- for the 3 possible genders of speakers (M (male), F (female) and U (unknown)) and for all :
				- the number of utterances
				- the number of speakers
				- the total duration
				- the average duration
				- the minimum duration
				- the maximum duration

**Partitioning**:

Thanks to the script "prep_json_partitioning.py", the total duration of speech is split between the different jsons files :

- dev_files.json : filtered data --> 10% of the total duration
- test_files.json : filtered data --> 10% of the total duration
- train_files.json : all the other audio --> 80% of total duration
- all_files.json : all the audios --> 100% of total duration


|      Gender     |       ALL       |      TRAIN      |       DEV       |       TEST      |
|-----------------|-----------------|-----------------|-----------------|-----------------|
|      Male       |     19345       |     17329       |      1015       |      1001       |
|     Female      |      8261       |      5600       |      1317       |      1344       |
|    Unknown      |       879       |       879       |         0       |         0       |
|      All        |     28485       |     23808       |      2332       |      2345       |

Number of files according to gender and partitions (train, dev and test).



|    Category     |       ALL       |      TRAIN      |       DEV       |       TEST      |
|-----------------|-----------------|-----------------|-----------------|-----------------|
|     animaux     |       160       |       108       |        31       |        21       |
|audiocite-juniors|        35       |        18       |         7       |        10       |
|      charme     |       166       |       166       |         0       |         0       |
|      contes     |      2430       |      1711       |       415       |       304       |
|     cuisine     |        39       |        35       |         3       |         1       |
|    documents    |      1494       |      1191       |       181       |       122       |
|     histoire    |      1341       |      1167       |        99       |        75       |
|    nouvelles    |      2772       |      1721       |       534       |       517       |
|   philosophies  |      1052       |       773       |        53       |       226       |
| planete-actuelle|       145       |       145       |         0       |         0       |
|     poesies     |      2274       |      1956       |       160       |       158       |
|    religions    |       777       |       777       |         0       |         0       |
|      romans     |     14664       |     13088       |       713       |       863       |
| science-fiction |       478       |       349       |       117       |        12       |
|     theatre     |       658       |       603       |        19       |        36       |
|       All       |     28485       |     23808       |      2332       |      2345       |

Number of files according to book category and partitions (train, dev and test).

































